@@ -38,7 +38,7 @@
 #include <kiconloader.h>
 #include <kimageio.h>
 #include <klineedit.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <knuminput.h>
 #include <ktextedit.h>
 #include <kurlrequester.h>
@@ -51,7 +51,7 @@
 #include <tqsqlquery.h>
 #include <tqvbox.h>
 #include <tqvbuttongroup.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 #define IMAGE_INTERNAL i18n("Image Saved in KBarcode")
 
