@@ -215,7 +215,7 @@ TQString tec452(const TQString &url, int count, const TQString &art, const TQStr
 TQString convZeros( int count, int zeros )
 {
 TQString str= TQString("%1").arg(count);
-int l=strlen(str); //get the string length
+int l=strlen(str.latin1()); //get the string length
 for(;l<zeros;l++) str = TQString("0") + str;
 return str;
 }
@@ -640,7 +640,7 @@ int fd, res;
 char buf[1];
 TQString result;
 
-fd = open(file, O_RDONLY);
+fd = open(file.local8Bit(), O_RDONLY);
 if (fd <0) return "Port Error.";
 res=read(fd,buf,1);
 while (res == 1){
